<TS language="ka" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>ახალი მისამართის შექმნა</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>შექმ&amp;ნა</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>მონიშნული მისამართის კოპირება სისტემურ კლიპბორდში</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;კოპირება</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>მონიშნული მისამართის წაშლა სიიდან</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;წაშლა</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>ფრაზა-პაროლის დიალოგი</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>შეიყვანეთ ფრაზა-პაროლი</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>ახალი ფრაზა-პაროლი</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>გაიმეორეთ ახალი ფრაზა-პაროლი</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>საფულე</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>მიმ&amp;ოხილვა</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>საფულის ზოგადი მიმოხილვა</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;გაგზავნა</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;მიღება</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>ტრანსაქციების ისტორიის დათვალიერება</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;გასვლა</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>გასვლა</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;ოპციები</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;ჩვენება/დაფარვა</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>საფულის &amp;დაშიფრვა</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>ფრაზა-პაროლის შე&amp;ცვლა</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>საფულის დაშიფრვის ფრაზა-პაროლის შეცვლა</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>ხელ&amp;მოწერა</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;ვერიფიკაცია</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>და&amp;ხვეწის ფანჯარა</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>დახვეწისა და გიაგნოსტიკის კონსოლის გაშვება</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ფაილი</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;პარამეტრები</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;დახმარება</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>განახლებულია</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>ჩართვა...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>გაგზავნილი ტრანსაქციები</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>მიღებული ტრანსაქციები</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>საფულე &lt;b&gt;დაშიფრულია&lt;/b&gt; და ამჟამად &lt;b&gt;დაბლოკილია&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>რაოდენობა:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ბაიტები:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>თანხა:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>საკომისიო:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>დამატებითი საკომისიო:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>ხურდა:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>თანხა</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>თარიღი</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>დადასტურება</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>დადასტურებულია</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>მისამართის შეცვლა</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>ნიშნუ&amp;ლი</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>მის&amp;ამართი</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>ოპციები</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;მთავარი</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;ქსელი</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>პორტის გადამისამართება &amp;UPnP-ით</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;პორტი</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>პროქსის პორტი (მაგ.: 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;ფანჯარა</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>ფანჯრის მინიმიზებისას მხოლოდ იკონა სისტემურ ზონაში</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;მინიმიზება სისტემურ ზონაში პროგრამების პანელის ნაცვლად</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>მ&amp;ინიმიზება დახურვისას</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;ჩვენება</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>სამომხმარებ&amp;ლო ენა:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>ერთეუ&amp;ლი:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>აირჩიეთ გასაგზავნი თანხის ნაგულისხმევი ერთეული.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;გაუქმება</translation>
    </message>
    <message>
        <source>default</source>
        <translation>ნაგულისხმევი</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>პროქსის მისამართი არასწორია.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>ფორმა</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>ხელმისაწვდომია:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>თქვენი ხელმისაწვდომი ნაშთი</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>მოუმზადებელია:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>სულ:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>თქვენი სრული მიმდინარე ბალანსი</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>მიუწვდ.</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>კლიენტის ვერსია</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;ინფორმაცია</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>სტარტის დრო</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>შეერთებების რაოდენობა</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>ბლოკთა ჯაჭვი</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>ბლოკების მიმდინარე რაოდენობა</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>ბოლო ბლოკის დრო</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;შექმნა</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;წაშლა</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;კონსოლი</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;ქსელის ტრაფიკი</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>სულ:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>შემომავალი:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>გამავალი:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>დახვეწის ლოგ-ფაილი</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>კონსოლის გასუფთავება</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>კლავიშები "ზევით" და "ქვევით" - ისტორიაში მოძრაობა, &lt;b&gt;Ctrl-L&lt;/b&gt; - ეკრანის გასუფთავება.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>აკრიფეთ &lt;b&gt;help&lt;/b&gt; ფაშვებული ბრძანებების სანახავად.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>მონეტების გაგზავნა</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>ხარჯები...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>არჩეულია ავტომატურად</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>არ არის საკმარისი თანხა!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>რაოდენობა:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ბაიტები:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>თანხა:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>საკომისიო:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>დამატებითი საკომისიო:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>გაგზავნა რამდენიმე რეციპიენტთან ერთდროულად</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;რეციპიენტის დამატება</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>გ&amp;ასუფთავება</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>გაგზავნის დადასტურება</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>გაგ&amp;ზავნა</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;რაოდენობა</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>ადრესა&amp;ტი:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>მესიჯი:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>ნიშნუ&amp;ლი:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>მისამართის ჩასმა კლიპბორდიდან</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>ხელმოწერები - მესიჯის ხელმოწერა/ვერიფიკაცია</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>მე&amp;სიჯის ხელმოწერა</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>მისამართის ჩასმა კლიპბორდიდან</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>აკრიფეთ ხელმოსაწერი მესიჯი</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>მიმდინარე ხელმოწერის კოპირება კლიპბორდში</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;მესიჯის ხელმოწერა</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>ხელმოწერის ყველა ველის წაშლა</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>გ&amp;ასუფთავება</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>მესიჯის &amp;ვერიფიკაცია</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>ვერიფიკაციის ყველა ველის წაშლა</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>ტრანსაქციის დაწვრილებითი აღწერილობა</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>ვერ ხერხდება პორტების მიყურადება. თუ გსურთ, გამოიყენეთ -listen=0.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>არასწორია მისამართი -proxy: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>მისამართების ჩატვირთვა...</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>-onlynet-ში მითითებულია უცნობი ქსელი: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>არ არის საკმარისი თანხა</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>ბლოკების ინდექსის ჩატვირთვა...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>საფულის ჩატვირთვა...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>ვერ ხერხდება ნაგულისხმევი მისამართის ჩაწერა</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>სკანირება...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>ჩატვირთვა დასრულებულია</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>შეცდომა</translation>
    </message>
</context>
</TS>